@@ -1,5 +1,5 @@
 package Amazon::DynamoDB::20120810;
-$Amazon::DynamoDB::20120810::VERSION = '0.30';
+$Amazon::DynamoDB::20120810::VERSION = '0.31';
 use strict;
 use warnings;
 
@@ -7,7 +7,7 @@ use warnings;
 use Future;
 use Future::Utils qw(repeat try_repeat);
 use POSIX qw(strftime);
-use JSON::XS;
+use JSON::MaybeXS qw(decode_json encode_json);
 use MIME::Base64;
 use List::Util;
 use List::MoreUtils;
@@ -26,8 +26,6 @@ BEGIN {
 };
 
 
-my $json = JSON::XS->new;
-
 
 sub new {
     my $class = shift;
@@ -126,7 +124,7 @@ method describe_table(TableNameType :$TableName!) {
     $self->_process_request($req,
                             sub { 
                                 my $content = shift; 
-                                $json->utf8->decode($content)->{Table};
+                                decode_json($content)->{Table};
                             });
 }
 
@@ -138,7 +136,7 @@ method delete_table(TableNameType :$TableName!) {
     $self->_process_request($req,
                             sub {
                                 my $content = shift;
-                                $json->utf8->decode($content)->{TableDescription}
+                                decode_json($content)->{TableDescription}
                             });
 }
 
@@ -176,7 +174,7 @@ method each_table(CodeRef $code,
         $self->_process_request($req,
                                 sub {
                                     my $result = shift;
-                                    my $data = $json->utf8->decode($result);
+                                    my $data = decode_json($result);
                                     for my $tbl (@{$data->{TableNames}}) {
                                         $code->($tbl);
                                     }
@@ -288,7 +286,7 @@ method get_item(CodeRef $code,
         $req, 
         sub {
             my $result = shift;
-            my $data = $json->utf8->decode($result);
+            my $data = decode_json($result);
             $code->(_decode_item_attributes($data->{Item}));
         });
 }
@@ -350,7 +348,7 @@ method batch_write_item(BatchWriteRequestItemsType :$RequestItems! where { scala
             $req,
             sub {
                 my $result = shift;
-                my $data = $json->utf8->decode($result);
+                my $data = decode_json($result);
                     
                 if (defined($data->{UnprocessedItems})) {
                     foreach my $table_name (keys %{$data->{UnprocessedItems}}) {
@@ -426,7 +424,7 @@ method batch_get_item(CodeRef $code,
             $req,
             sub {
                 my $result = shift;
-                my $data = $json->utf8->decode($result);
+                my $data = decode_json($result);
                 foreach my $table_name (keys %{$data->{Responses}}) {
                     foreach my $item (@{$data->{Responses}->{$table_name}}) {
                         $code->($table_name, _decode_item_attributes($item));
@@ -551,7 +549,7 @@ method make_request(Str :$target,
     $req->header( 'Date' => $http_date );
     $req->header( 'x-amz-target', 'DynamoDB_'. $api_version. '.'. $target );
     $req->header( 'content-type' => 'application/x-amz-json-1.0' );
-    $payload = $json->utf8->encode($payload);
+    $payload = encode_json($payload);
     $req->content($payload);
     $req->header( 'Content-Length' => length($payload));
     
@@ -600,7 +598,7 @@ method _scan_or_query_process (Str $target,
             $req,
             sub {
                 my $result = shift;
-                my $data = $json->utf8->decode($result);
+                my $data = decode_json($result);
                 
                 for my $entry (@{$data->{Items}}) {
                     $code->(_decode_item_attributes($entry));
@@ -735,7 +733,7 @@ method _process_request(HTTP::Request $req, CodeRef $done?) {
                             $do_retry = 1;
                             $current_retry++;
                         } elsif ($resp->code == 400) {
-                            $r = $json->utf8->decode($resp->decoded_content);
+                            $r = decode_json($resp->decoded_content);
                             if ($r->{__type} =~ /ProvisionedThroughputExceededException$/) {
                                 # Need to sleep
                                 $do_retry = 1;
@@ -962,7 +960,7 @@ sub _make_payload {
 }
 
 fun _decode_single_item_change_response(Str $response) {
-    my $r = $json->utf8->decode($response);
+    my $r = decode_json($response);
     if (defined($r->{Attributes})) {
         $r->{Attributes} = _decode_item_attributes($r->{Attributes});
     }
@@ -1008,7 +1006,7 @@ Amazon::DynamoDB::20120810
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 DESCRIPTION
 
